==> suir-component-mapper-3.18.0.tgz: package/esm/tabs/tabs.js <==
import _extends from "@babel/runtime/helpers/extends";
import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import Tab from "semantic-ui-react/dist/es/modules/Tab/Tab.js";
import TabPane from "semantic-ui-react/dist/es/modules/Tab/TabPane.js";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";

var TabContent = function TabContent(_ref) {
  var name = _ref.name,
      fields = _ref.fields,
      formOptions = _ref.formOptions;
  return /*#__PURE__*/React.createElement(Fragment, {
    key: name
  }, formOptions.renderForm(fields, formOptions));
};

TabContent.propTypes = {
  name: PropTypes.string.isRequired,
  fields: PropTypes.array.isRequired,
  formOptions: PropTypes.shape({
    renderForm: PropTypes.func.isRequired
  }).isRequired
};

var FormTabs = function FormTabs(_ref2) {
  var fields = _ref2.fields,
      TabProps = _ref2.TabProps,
      TabPaneProps = _ref2.TabPaneProps;
  var formOptions = useFormApi();
  var panes = fields.map(function (field, index) {
    return {
      menuItem: field.title,
      pane: /*#__PURE__*/React.createElement(TabPane, _extends({}, TabPaneProps, {
        key: index
      }), /*#__PURE__*/React.createElement(TabContent, _extends({}, field, {
        formOptions: formOptions
      })))
    };
  });
  return /*#__PURE__*/React.createElement(Tab, _extends({
    renderActiveOnly: false
  }, TabProps, {
    panes: panes
  }));
};

FormTabs.propTypes = {
  fields: PropTypes.array.isRequired,
  TabProps: PropTypes.object,
  TabPaneProps: PropTypes.object
};
FormTabs.defaultProps = {
  TabProps: {},
  TabPaneProps: {}
};
export default FormTabs;

==> suir-component-mapper-4.0.0.tgz: package/esm/tabs/tabs.js <==
import _extends from "@babel/runtime/helpers/extends";
import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import Tab from "semantic-ui-react/dist/es/modules/Tab/Tab.js";
import TabPane from "semantic-ui-react/dist/es/modules/Tab/TabPane.js";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";

var TabContent = function TabContent(_ref) {
  var name = _ref.name,
      fields = _ref.fields,
      formOptions = _ref.formOptions;
  return /*#__PURE__*/React.createElement(Fragment, {
    key: name
  }, formOptions.renderForm(fields, formOptions));
};

TabContent.propTypes = {
  name: PropTypes.string.isRequired,
  fields: PropTypes.array.isRequired,
  formOptions: PropTypes.shape({
    renderForm: PropTypes.func.isRequired
  }).isRequired
};

var FormTabs = function FormTabs(_ref2) {
  var fields = _ref2.fields,
      _ref2$TabProps = _ref2.TabProps,
      TabProps = _ref2$TabProps === void 0 ? {} : _ref2$TabProps,
      _ref2$TabPaneProps = _ref2.TabPaneProps,
      TabPaneProps = _ref2$TabPaneProps === void 0 ? {} : _ref2$TabPaneProps;
  var formOptions = useFormApi();
  var panes = fields.map(function (field, index) {
    return {
      menuItem: field.title,
      pane: /*#__PURE__*/React.createElement(TabPane, _extends({}, TabPaneProps, {
        key: index
      }), /*#__PURE__*/React.createElement(TabContent, _extends({}, field, {
        formOptions: formOptions
      })))
    };
  });
  return /*#__PURE__*/React.createElement(Tab, _extends({
    renderActiveOnly: false
  }, TabProps, {
    panes: panes
  }));
};

FormTabs.propTypes = {
  fields: PropTypes.array.isRequired,
  TabProps: PropTypes.object,
  TabPaneProps: PropTypes.object
};
export default FormTabs;
